// @bun
// src/index.ts
import process from "process";
import {consola, createConsola} from "consola";
import {ExitCode} from "@stacksjs/types";
import {logger as logConfig} from "@stacksjs/config";
import {logsPath} from "@stacksjs/path";
import {buddyOptions, prompt as getPrompt} from "@stacksjs/cli";
function logLevel() {
  const verboseRegex = /--verbose(?!(\s*=\s*false|\s+false))(\s+|=true)?($|\s)/;
  if (verboseRegex.test(buddyOptions().trim()))
    return 4;
  return logConfig.level;
}
async function writeToLogFile(message) {
  const formattedMessage = `[${new Date().toISOString()}] ${message}\n`;
  try {
    const file = Bun.file(logFilePath);
    const writer = file.writer();
    const text = await file.text();
    writer.write(`${text}\n`);
    writer.write(`${formattedMessage}\n`);
    await writer.end();
  } catch (error) {
    const file = Bun.file(logFilePath);
    const writer = file.writer();
    writer.write(`${formattedMessage}\n`);
    await writer.end();
  }
}
function dump(...args) {
  args.forEach((arg) => log.debug(arg));
}
function dd(...args) {
  args.forEach((arg) => log.debug(arg));
  process.exit(ExitCode.FatalError);
}
function echo(...args) {
  console.log(...args);
}
var logger = createConsola({
  level: logLevel()
});
var logFilePath = logsPath("console.log");
var log = {
  async info(...arg) {
    logger.info(...arg);
    await writeToLogFile(`INFO: ${arg}`);
  },
  async success(msg) {
    logger.success(msg);
    await writeToLogFile(`SUCCESS: ${msg}`);
  },
  async error(err, options) {
    handleError(err, options);
    await writeToLogFile(`ERROR: ${err}`);
  },
  async warn(arg) {
    logger.warn(arg);
    await writeToLogFile(`WARN: ${arg}`);
  },
  async debug(...arg) {
    if (process.env.APP_ENV === "production" || process.env.APP_ENV === "prod")
      return await writeToLogFile(`DEBUG: ${arg}`);
    logger.debug(arg);
    await writeToLogFile(`DEBUG: ${arg}`);
  },
  async start(...arg) {
    logger.start(arg);
    await writeToLogFile(`START: ${arg}`);
  },
  box: logger.box,
  get prompt() {
    return getPrompt();
  },
  dump,
  dd,
  echo
};
export {
  logger,
  logLevel,
  logFilePath,
  log,
  echo,
  dump,
  dd,
  consola
};
